# Functions for numerical analogy

This package provides two functions for:

* computing the analogical power (with the ordering)
* solving a numerical analogical equation

# Installation

Rename `numerical-analogy-master` into `num_nlg` and install using:

```shell
> pip install num_nlg/
```

# Computation of analogical powers for analogies between positive non-null real numbers.

**Theorem:**
for any quadruple of positive real numbers, ordered in increasing order,
there exists a unique numerical analogy between these numbers.
```math
\forall (a, b, c, d) \in \left(\mathbb{R}_+\right)^4,\; a < b < c <d, \;\;
\exists! p \in \mathbb{R} \;/\; a:b::^p:c:d.
```

**Definition:**
An analogy of order $`p`$ holds between four numbers when
the generalized mean in $`p`$ of the extremes
is equal to
the generalized mean in $`p`$ of the means.
```math
m_p(a, d) = m_p(b, c)
```
where
```math
m_p(a, d) = \lim_{r \rightarrow p} \left( \dfrac{1}{2} (a^r + d^r) \right)^{1/r}.
```

**Library purpose:**
The present library computes such a $`p`$ given a quadruple $`(a, b, c, d)`$.
It also takes care of the cases of equality,
where $`p`$ equals to $`-\infty`$ or $`+\infty`$
or
where $`p`$ is not unique ($`p`$ ranges over all $`\mathbb{R} \cup \{ -\infty, +\infty\}`$).
